@@ -1,5 +1,6 @@
 import asyncio
 from functools import wraps
+from typing import Optional
 
 from channels.db import database_sync_to_async
 from django.conf import settings
@@ -8,37 +9,50 @@ from django.db import transaction
 from djangochannelsrestframework.consumers import AsyncAPIConsumer
 
 
-def detail_action(**kwargs):
-    """
-    Used to mark a method on a ResourceBinding that should be routed for detail actions.
-    """
-
-    def decorator(func):
-        func.action = True
-        func.detail = True
-        func.kwargs = kwargs
-        return func
-
-    return decorator
-
-
-def list_action(**kwargs):
-    """
-    Used to mark a method on a ResourceBinding that should be routed for list actions.
-    """
-
-    def decorator(func):
-        func.action = True
-        func.detail = False
-        func.kwargs = kwargs
-        return func
-
-    return decorator
-
-
-def action(atomic=None, **kwargs):
+def action(atomic: Optional[bool] = None, **kwargs):
     """
     Mark a method as an action.
+
+    .. note::
+
+        Should be used as a method decorator eg: `@action()`
+
+
+    It can be used on both `async` and `sync` methods.
+
+    .. code-block:: python
+
+        from djangochannelsrestframework.decorators import action
+
+        class MyConsumer(AsyncAPIConsumer):
+            queryset = User.objects.all()
+            serializer_class = UserSerializer
+
+            @action()
+            async def delete_user(self, request_id, user_pk, **kwargs):
+                ...
+
+    Methods decorated with `@action()` will be called when a json message arrives
+    from the client with a matching `action` name.
+
+    The default way of sending a message to call an action is:
+
+    .. code-block:: javascript
+
+        {
+         action: "delete_user",
+         request_id: 42,
+         user_pk: 82
+        }
+
+
+    You can alter how :class:`AsyncAPIConsumer` matches the action using the
+    :meth:`get_action_name` method.
+
+
+    When using on `sync` methods you can provide an additional
+    option `atomic=True` to forcefully wrap the method in a transaction.
+    The default value for atomic is determined by django's default db `ATOMIC_REQUESTS` setting.
     """
 
     def decorator(func):
