@@ -1,12 +1,10 @@
-from typing import Any, Dict, Type, Optional, List, OrderedDict, Union
+from typing import Any, Dict, Type, Optional
 
 from django.db.models import QuerySet, Model
 from rest_framework.generics import get_object_or_404
 from rest_framework.serializers import Serializer
-from rest_framework.utils.serializer_helpers import ReturnDict, ReturnList
 
 from djangochannelsrestframework.consumers import AsyncAPIConsumer
-from djangochannelsrestframework.settings import api_settings
 
 
 class GenericAsyncAPIConsumer(AsyncAPIConsumer):
