@@ -1,11 +1,10 @@
 from typing import Any, Tuple, Dict, Optional, OrderedDict, Union
-from djangochannelsrestframework.observer.model_observer import Action
-from rest_framework.utils.serializer_helpers import ReturnDict, ReturnList
+
 from rest_framework import status
 from rest_framework.utils.serializer_helpers import ReturnDict, ReturnList
 
-from .decorators import action
 from djangochannelsrestframework.settings import api_settings
+from djangochannelsrestframework.decorators import action
 
 
 class CreateModelMixin:
@@ -419,7 +418,7 @@ class DeleteModelMixin:
 
 
 class PaginatedModelListMixin(ListModelMixin):
-
+    permission_classes = api_settings.DEFAULT_PERMISSION_CLASSES
     pagination_class = api_settings.DEFAULT_PAGINATION_CLASS
 
     @action()
